@@ -1,8 +1,10 @@
+from .agno import AgnoInstrumentation
 from .anthropic import AnthropicInstrumentation
 from .autogen import AutogenInstrumentation
 from .aws_bedrock import AWSBedrockInstrumentation
 from .cerebras import CerebrasInstrumentation
 from .chroma import ChromaInstrumentation
+from .cleanlab import CleanLabInstrumentation
 from .cohere import CohereInstrumentation
 from .crewai import CrewAIInstrumentation
 from .crewai_tools import CrewaiToolsInstrumentation
@@ -10,6 +12,7 @@ from .dspy import DspyInstrumentation
 from .embedchain import EmbedchainInstrumentation
 from .gemini import GeminiInstrumentation
 from .google_genai import GoogleGenaiInstrumentation
+from .graphlit import GraphlitInstrumentation
 from .groq import GroqInstrumentation
 from .langchain import LangchainInstrumentation
 from .langchain_community import LangchainCommunityInstrumentation
@@ -21,17 +24,12 @@ from .milvus import MilvusInstrumentation
 from .mistral import MistralInstrumentation
 from .ollama import OllamaInstrumentor
 from .openai import OpenAIInstrumentation
+from .phidata import PhiDataInstrumentation
 from .pinecone import PineconeInstrumentation
 from .pymongo import PyMongoInstrumentation
 from .qdrant import QdrantInstrumentation
 from .vertexai import VertexAIInstrumentation
 from .weaviate import WeaviateInstrumentation
-from .cerebras import CerebrasInstrumentation
-from .milvus import MilvusInstrumentation
-from .google_genai import GoogleGenaiInstrumentation
-from .graphlit import GraphlitInstrumentation
-from .phidata import PhiDataInstrumentation
-from .agno import AgnoInstrumentation
 
 __all__ = [
     "AnthropicInstrumentation",
@@ -65,4 +63,5 @@ __all__ = [
     "GraphlitInstrumentation",
     "PhiDataInstrumentation",
     "AgnoInstrumentation",
+    "CleanLabInstrumentation",
 ]
